import { __assign, __rest } from "tslib";
import React, { useEffect, useRef } from 'react';
import { motion } from 'framer-motion';
import clsx from 'clsx';
export default function DrawerContent(_a) {
    var className = _a.className, children = _a.children, onClose = _a.onClose, props = __rest(_a, ["className", "children", "onClose"]);
    var dialogRef = useRef(null);
    useEffect(function () {
        var handleKeyPress = function (e) {
            if (e.key === 'Escape') {
                onClose();
            }
        };
        window.addEventListener('keydown', handleKeyPress);
        return function () {
            window.removeEventListener('keydown', handleKeyPress);
        };
    }, []);
    useEffect(function () {
        var handleClickOutside = function (event) {
            if (dialogRef.current &&
                !dialogRef.current.contains(event.target)) {
                onClose();
            }
        };
        document.addEventListener('mousedown', handleClickOutside);
        return function () {
            document.removeEventListener('mousedown', handleClickOutside);
        };
    }, [onClose]);
    return (React.createElement(motion.div, null,
        React.createElement("div", __assign({ ref: dialogRef, className: clsx(className, 'fixed inset-x-0 bottom-0 z-50 mt-24 flex h-auto flex-col rounded-t-[10px] border-t border-[#e4e4e7] dark:border-[#27272a] bg-white dark:bg-black') }, props),
            React.createElement("div", { onClick: onClose, className: "mx-auto mt-4 h-2 w-[100px] rounded-full bg-[#e9f0ff] dark:bg-[#2b2b36]" }),
            children)));
}
//# sourceMappingURL=DrawerContent.js.map